// IDeviceManager.aidl
package com.ft.possystemapi.server.device;

import android.os.IBinder;
import java.util.List;

interface IDeviceManager {

    /**
     * Erase all data, execute factory reset
     */
    boolean factoryReset();

    /**
     * get application name by PackageInfo
     *
     * @param packageInfo
     * @return application name
     */
    // String getApplicationName(in PackageInfo packageInfo);

    /**
     * get application name by PackageInfo
     *
     * @param packageInfo
     * @return application packagename
     */
    // String getApplicationPackageName(in PackageInfo packageInfo);

    /**
     * get application version code by PackageInfo
     *
     * @param packageInfo
     * @return application version code
     */
    // long getApplicationVersionCode(in PackageInfo packageInfo);

    /**
     * get application version name
     *
     * @param packageInfo
     * @return application version name
     */
    // String getApplicationVersionName(in PackageInfo packageInfo);

    /**
     * Returns the battery capacity, if available, in milli Amp Hours. If not available,
     * it returns zero.
     *
     * @return the battery capacity in mAh
     */
    double getBatteryCapacity();

    /**
     * Get battery level of device
     *
     * @return Battery level percent of the device.
     */
    int getBatteryLevel();

    /**
     * Get build number of device
     *
     * @return build number
     */
    String getBuildNumber();

    /**
     * Get current CPU frequency
     *
     * @return current CPU frequency, e.g. “1300 MHz”. Return "N/A" if get CPU frequency failed.
     */
    String getCPURate();

    /**
     * get utc format time string of timestamp
     *
     * @param timeStamp
     * @return utc format time string
     */
    String getDateTime(long timeStamp);

    /**
     * Get CPU display name of the device
     *
     * @return The CPU display name of device, or return null if get CPU name fail.
     */
    String getDeviceCpuName();

    /**
     * get front camera information of device
     *
     * @return front camera information, e.g. “gc2385”
     */
    String getDeviceFrontCameraInfo();

    /**
     * Get the IMEI (International Mobile Equipment Identity)
     *
     * @param slotIndex of which IMEI is returned
     * @return Returns the IMEI (International Mobile Equipment Identity). Return null if IMEI is not available.
     */
    String getDeviceImei(int slotIndex);

    /**
     * get screen LCD information of device
     *
     * @return LCD information, e.g. “ili9881d_720p_video”
     */
    String getDeviceLcdInfo();

    /**
     * Get device platform
     *
     * @return device platform. Return null if get device platform fail.
     */
    String getDevicePlatform();

    /**
     * get rear camera information of device
     *
     * @return rear camera information, e.g. “ov8856_2lane”
     */
    String getDeviceRearCameraInfo();

    /**
     * Get available size of External Sdcard, unit in bytes
     *
     * @return available size of External sdcard. Return 0 if no External sdcard is available.
     */
    long getDeviceSdAvailableSize();

    // String getDeviceState();

    /**
     * get screen TP information of device
     *
     * @return TP information, e.g. “GT1158_000101(Patch)_10200(Mask)_02(SensorID)”
     */
    String getDeviceTpInfo();

    /**
     * get ipv4 address of device
     * @param info WifiInfo
     * @return ipv4 address
     */
    // String getIpv4Address(in WifiInfo info);

    /**
     * Get the factory Wi-Fi MAC address
     *
     * @return The factory Wi-Fi MAC address, or return null if get MAC address fail.
     */
    String getMacAddress();

    /**
     * Get available memory size of device, unit in bytes
     *
     * @return Available Memory size of device, Return 0 if get memory fail.
     */
    long getMemoryAvailableSize();

    /**
     * Get total memory size of device
     *
     * @return Total memory size of device, in bytes. Return 0 if get memory fail.
     */
    long getMemoryTotalSize();

    /**
     * compute Memory usage percent of device
     *
     * @return Return memory usage percent.
     */
    float getMemoryUsePercenTile();

    String getModelName();

    String getOsVersion();

    /**
     * Get available size of the device ROM, unit in bytes
     *
     * @return Available size of device ROM, or return 0 if get available ROM size fail.
     */
    long getRomAvailableSize();

    /**
     * Get total ROM size of device, unit in bytes
     *
     * @return Total size of device ROM, or return 0 if get total size fail
     */
    long getRomTotalSize();


    /**
     * Get PosSysAPI lib version
     */
    String getSdkVersion();

    /**
     * Get device ROM space usage percent
     *
     * @return ROM space usage percent
     */
    double getStorageUsePercenTile();

    /**
     * get utc format string of current time
     *
     * @return utc format string of
     */
    String getUpdateTime();

    /**
     * Returns the current link speed in {@link android.net.wifi.WifiInfo.LINK_SPEED_UNITS}.
     *
     * @param info WifiInfo
     * @return the link speed or {@link android.net.wifi.WifiInfo.LINK_SPEED_UNKNOWN} if link speed is unknown.
     */
    // int getWifiLinkSpeed(in WifiInfo info);

    /**
     * Returns the received signal strength indicator of the current 802.11
     * network, in dBm.
     *
     * <p>Use {@link android.net.wifi.WifiManager#calculateSignalLevel} to convert this number into
     * an absolute signal level which can be displayed to a user.
     *
     * @return the RSSI.
     */
    // int getWifiSignalStrength(in WifiInfo info);

    /**
     * Returns the service set identifier (SSID) of the current 802.11 network.
     *
     * @param info WifiInfo
     * @return the SSID.
     */
    // String getWifiSSID(in WifiInfo info);

    /**
     * Get the logical density of the display.
     *
     * @return a scaling factor for the Density Independent Pixel unit
     */
    float getWindowDensity();

    /**
     * Get window density dpi of the device
     *
     * @return density dpi, e.g. “320 dpi”
     */
    String getWindowDensityDpi();

    /**
     * Get window scaled density
     *
     * @return scaled density, e.g. “319 ppi”
     */
    String getWindowScaledDensity();

    /**
     * Get screen resolution of device
     *
     * @return screen resolution, e.g. “1280 x 720”
     */
    String getWindowScreenResolution();

    /**
     * Get Physical size of Screen window, unit by inch
     *
     * @return The physical size of screen, e.g. “4.60” inches
     */
    double getWindowScreenSize();

    /**
    * Push notifications  messages
    */
    void pushNotificationsMsg(String msg);

    /**
    * Reboot device
    */
    boolean rebootDevice();

    /**
     * Set an APP as Launcher app
     *
     * @param packageName
     * @param className
     */
    boolean setDefaultLauncher(String packageName, String className);

    /**
     * Set the boot animation. The zip file must follow the Android boot animation format.
     *
     * @param animationPath Path to the zip file containing the animation (e.g.: "/sdcard/bootanimation.zip")
     */
    boolean setDeviceAnimation(String animationPath);

    /**
     * Set the first static boot frame
     *
     * @param logoBytes Bytes array of boot logo file.
     */
    boolean setDeviceLogo(in byte[] logoBytes);

    /**
     * Set a picture as device wallpaper
     * @param wallpaperPath
     */
    boolean setDeviceWallpaper(String wallpaperPath);

    /**
    * Shutdown device
    */
    boolean shutdownDevice();

    /**
    * get device screenshot picture
    * @return the screenshot file path
    */
    String getScreenshot();

    /**
    * Write SSL/TLS certificate file
    * @param data
    * @param fileName
    */
    boolean writeCertificateFile(in byte [] data,String fileName);

    /**
    * read SSL/TLS certificate file
    * @param fileName
    */
    byte [] readCertificateFile(String fileName);

    /**
     * Set screen brightness
     *
     * @param brightness Screen brightness value. Must be greater than 10 and less than 255.
     */
    void setScreenBrightness(int brightness);

    /**
     * Set device screen timeout
     *
     * @param value screen timeout, unit by milliseconds,
     *              the value can be:
     *              15000---15 seconds
     *              30000---30 seconds
     *              60000---1 minute
     *              120000---2 minutes
     *              300000---5 minutes
     *              600000---10 minutes
     *              1800000---30 minutes
     *              Integer.MAX_VALUE---never
     */
    boolean setDefaultScreenTimeout(int value);

    /**
     * Get screen brightness value[0~255]
     *
     * @return brightness value[0~255]
     */
    int getScreenBrightness();

    /**
     * get default screen timeout, unit by ms
     *
     * @return default screen timeout, unit by ms
     */
    int getDefaultScreenTimeout();

    /**
     * Add apn setting.
     *
     * @param apn setting, Use Telephony.Carriers fields for setting values in input argument ContentValues values.
     *
     * @return Uri of this apn setting in Android database.
     */
    Uri insertApn(in ContentValues apn);

    /**
     * Update apn setting.
     *
     * @param apn setting, Use Telephony.Carriers fields for setting values in input argument ContentValues values.
     */
    int updateApn(in ContentValues apn);

    /**
     * Delete apn setting.
     *
     * @param uri of this apn setting in Android database.
     */
    int deleteApn(in Uri uri);

    /**
     * Restore apn for terminal.
     */
    int setDefaultApn();

    /**
     * Get current apn setting.
     *
     * @return apn setting values.
     */
    ContentValues getCurrentApn();

    /**
     * Get apn setting list for specify Sim card
     *
     * @param subId subId of specify Sim card.
     * @return a list of apn setting
     */
    List<ContentValues> getApnListForSim(int subId);

    /**
     * Get apn setting list for system
     *
     * @return a list of apn setting
     */
    List<ContentValues> getApnListForSystem();

    /**
     * Switch apn setting by specify apnId
     *
     * @param apnId Apn id in android database.
     */
    void switchApn(String apnId);

    /**
     * Get preferred apn setting Id
     */
    String getPreferredApnId();

    boolean putSettingsInt(int tableType, String key, int value);

    boolean putSettingsString(int tableType, String key, String value);

    /**
     * Get USB virtual serial port status
     */
    boolean getUsbVirtualSerialPortEnabled();

    /**
     * Set USB virtual serial port status
     *
     * @param enabled If true is turn on, else false when turn off.
     */
    boolean setUsbVirtualSerialPortEnabled(boolean enabled);

    /**
     * Get device Model name for customer
     */
    String getDeviceModel();

    /**
     * Set the first static boot frame
     *
     * @param logoFilePath The full path of boot logo file. For Qualcomm device, the boot logo file should be ".raw" format, and for MTK device, it should be ".bmp" format.
     */
    boolean setBootLogo(String logoFilePath);

    /**
     * Returns the serial number for the given slotIndex, if applicable. Return null if it is
     * unavailable.
     *
     * @param slotIndex for which Sim Serial number is returned
     */
    String getSimSerialNumber(int slotIndex);

    /**
     * Get the device's current density.
     *
     * The screen density expressed as dots-per-inch.
     */
    int getDisplayDensityDpi();

    /**
     * Returns the default density for the default display.
     *
     * @return the default density of the specified display, or {@code -1} if
     * the display does not exist or the density could not be obtained
     */
    int getDefaultDisplayDensityDpi();

    /**
     * Asynchronously applies display density changes to the default display.
     * <p>
     * The change will be applied to the user specified by the value of
     * {@link UserHandle#myUserId()} at the time the method is called.
     *
     * @param densityDpi the density to force for the specified display
     */
    void setDisplayDensityDpi(int densityDpi);

    /**
     * Returns the unique subscriber ID, for example, the IMSI for a GSM phone.
     * Return null if it is unavailable.
     *
     * @param slotIndex whose subscriber id is returned
     */
     String getSubscriberId(int slotIndex);

}